rft1d
=====

One-Dimensional <b>Random Field Theory</b> in Python.

<b>rft1d</b> is a Python package for exploring and validating Random Field Theory (RFT)
expectations regarding upcrossings in univariate and multivariate 1D continua.
These expectations can be used to make statistical inferences regarding signals
observed in experimentally measured 1D continua including scalar and vector time series.


<b>Please cite:</b>

Pataky TC (2016) RFT1D: Smooth One-Dimensional Random Field Upcrossing Probabilities in Python.
<b>Journal of Statistical Software</b> 71(7): 1-22. https://doi.org/10.18637/jss.v071.i07
 
Documentation is available at:
[www.spm1d.org/rft1d](http://spm1d.org/rft1d)

Issues
------

Please report software bugs or other problems by searching existing issues or creating a new issue [here](https://github.com/0todd0000/rft1d/issues).
